@@ -28,7 +28,7 @@ class AES(object):
 	def __init__(self, passphrase=None):
 		
 		# check params.
-		response = r3sponse.parameters.check({
+		response = Response.parameters.check({
 			"passphrase:str":passphrase,})
 		if not response.success: raise ValueError(response.error)
 
@@ -42,7 +42,7 @@ class AES(object):
 		#
 	def encrypt(self, raw):
 		if raw in ["", b"", None, False]:
-			return r3sponse.error("Can not encrypt null data.")
+			return Response.error("Can not encrypt null data.")
 		raw = Formats.denitialize(raw)
 		response = self.get_key()
 		if not response.success: return response
@@ -55,13 +55,13 @@ class AES(object):
 		cipher = _AES_.new(key, _AES_.MODE_CBC, iv)
 		encrypted = base64.b64encode(iv + salt + cipher.encrypt(raw.encode()))
 		if raw != b"" and encrypted == b"":
-			return r3sponse.error("Failed to encrypt the specified data with the current passphrase / salt.")
-		return r3sponse.success("Successfully encrypted the specified data.", {
+			return Response.error("Failed to encrypt the specified data with the current passphrase / salt.")
+		return Response.success("Successfully encrypted the specified data.", {
 			"encrypted":encrypted,
 		})
 	def decrypt(self, enc):
 		if enc in ["", b"", None, False]:
-			return r3sponse.error("Can not decrypt null data.")
+			return Response.error("Can not decrypt null data.")
 		enc = Formats.denitialize(enc)
 		if isinstance(enc, str):
 			enc = enc.encode()
@@ -75,8 +75,8 @@ class AES(object):
 		cipher = _AES_.new(key, _AES_.MODE_CBC, iv)
 		decrypted = self.unpad(cipher.decrypt(enc[32:]))
 		if enc != b"" and decrypted == b"":
-			return r3sponse.error("Failed to decrypt the specified data with the current passphrase / salt.")
-		return r3sponse.success("Successfully decrypted the specified data.", {
+			return Response.error("Failed to decrypt the specified data with the current passphrase / salt.")
+		return Response.success("Successfully decrypted the specified data.", {
 			"decrypted":decrypted,
 		})
 	def get_key(self, salt=None):
@@ -86,7 +86,7 @@ class AES(object):
 			salt = salt.encode()
 		kdf = PBKDF2(self.passphrase, salt, 64, 1000)
 		key = kdf[:32]
-		return r3sponse.success("Successfully loaded the aes key.", {
+		return Response.success("Successfully loaded the aes key.", {
 			"key":key,
 			"salt":salt,
 		})
@@ -94,7 +94,7 @@ class AES(object):
 		length=16
 		chars = ''.join([string.ascii_uppercase, string.ascii_lowercase, string.digits])
 		salt = ''.join(random.choice(chars) for x in range(length))
-		return r3sponse.success("Successfully generated a salt.", {
+		return Response.success("Successfully generated a salt.", {
 			"salt":salt,
 		})
 
@@ -135,7 +135,7 @@ class AsymmetricAES(object):
 		if not response.success: return response
 		aes_encrypted = response["encrypted"]
 		if b" " in aes_encrypted:
-			return r3sponse.error("AES encrypt data contains invalid ' ' character(s).")
+			return Response.error("AES encrypt data contains invalid ' ' character(s).")
 
 		# encrypt aes key with rsa.
 		response = self.rsa.encrypt_string(passphrase, decode=False)
@@ -147,7 +147,7 @@ class AsymmetricAES(object):
 
 		# success.
 		if decode: encrypted = encrypted.decode()
-		return r3sponse.success("Successfully encrypted the specified data.", {
+		return Response.success("Successfully encrypted the specified data.", {
 			"encrypted":encrypted
 		})
 
@@ -162,7 +162,7 @@ class AsymmetricAES(object):
 			key,encrypted = unpack(string)
 		#except:
 		except KeyboardInterrupt:
-			return r3sponse.error("Unable to unpack the encrypted data.")
+			return Response.error("Unable to unpack the encrypted data.")
 
 		# decypt key with rsa.
 		response = self.rsa.decrypt_string(key, decode=False)
@@ -177,7 +177,7 @@ class AsymmetricAES(object):
 
 		# success.
 		if decode: decrypted = decrypted.decode()
-		return r3sponse.success("Successfully decrypted the specified data.", {
+		return Response.success("Successfully decrypted the specified data.", {
 			"decrypted":decrypted
 		})
 
@@ -187,7 +187,7 @@ class AsymmetricAES(object):
 		output = Formats.denitialize(output)
 
 		# check params.
-		response = r3sponse.parameters.check({
+		response = Response.parameters.check({
 			"input":input,
 			"output":output,})
 		if not response.success: return response
@@ -201,7 +201,7 @@ class AsymmetricAES(object):
 
 		# write out.
 		try: utils.__save_bytes__(output, response["encrypted"])
-		except: return r3sponse.error(f"Failed to write out encrypted file {output}.")
+		except: return Response.error(f"Failed to write out encrypted file {output}.")
 
 		# remove.
 		if remove and input != output: 
@@ -209,7 +209,7 @@ class AsymmetricAES(object):
 			except PermissionError: os.system(f"sudo rm -fr {input}")
 
 		# handler.
-		return r3sponse.success(f"Successfully encrypted file {input} to {output}.")
+		return Response.success(f"Successfully encrypted file {input} to {output}.")
 
 		#
 	def decrypt_file(self, input=None, output=None, remove=False, base64_encoding=False):
@@ -217,7 +217,7 @@ class AsymmetricAES(object):
 		output = Formats.denitialize(output)
 
 		# check params.
-		response = r3sponse.parameters.check({
+		response = Response.parameters.check({
 			"input":input,
 			"output":output,})
 		if not response.success: return response
@@ -231,7 +231,7 @@ class AsymmetricAES(object):
 		if base64_encoding:
 			decrypted = base64.b64decode(decrypted)
 		try: utils.__save_bytes__(output, decrypted)
-		except: return r3sponse.error(f"Failed to write out decrypted file {output}.")
+		except: return Response.error(f"Failed to write out decrypted file {output}.")
 
 		# remove.
 		if remove and input != output: 
@@ -239,7 +239,7 @@ class AsymmetricAES(object):
 			except PermissionError: os.system(f"sudo rm -fr {input}")
 
 		# handler.
-		return r3sponse.success(f"Successfully decrypted file {input} to {output}.")
+		return Response.success(f"Successfully decrypted file {input} to {output}.")
 
 		#
 	def encrypt_directory(self, input=None, output=None, remove=False):
@@ -249,9 +249,9 @@ class AsymmetricAES(object):
 		# checks.
 		file_path = FilePath(input)
 		if not file_path.exists():
-			return r3sponse.error(f"Directory [{input}] does not exist.")
+			return Response.error(f"Directory [{input}] does not exist.")
 		if not file_path.directory():
-			return r3sponse.error(f"Directory path [{input}] is not a directory.")
+			return Response.error(f"Directory path [{input}] is not a directory.")
 
 		# zip path.
 		if output == None:
@@ -259,13 +259,13 @@ class AsymmetricAES(object):
 			else: zip_path = str(input)
 			zip_path = f'{zip_path}.enc.zip'
 		elif ".enc.zip" not in output:
-			return r3sponse.error(f"Invalid output format [{output}], the format must end with [***.enc.zip]")
+			return Response.error(f"Invalid output format [{output}], the format must end with [***.enc.zip]")
 		else:
 			zip_path = output
 
 		# check output.
 		if Files.exists(zip_path):
-			return r3sponse.error(f"output path [{zip_path}] already exists.")
+			return Response.error(f"output path [{zip_path}] already exists.")
 
 		# create zip.
 		zip = Zip(path=zip_path)
@@ -279,10 +279,10 @@ class AsymmetricAES(object):
 					os.system(f"rm -fr {input}")
 					if Files.exists(input): raise PermissionError("")
 				except PermissionError: os.system(f"sudo rm -fr {input}")
-			return r3sponse.success(f"Successfully encrypted directory [{input}].")
+			return Response.success(f"Successfully encrypted directory [{input}].")
 		else:
 			zip.file_path.delete(forced=True)
-			return r3sponse.error(f"Failed to encrypt directory [{input}].")
+			return Response.error(f"Failed to encrypt directory [{input}].")
 
 		#
 	def decrypt_directory(self, input=None, output=None, remove=False):
@@ -292,32 +292,32 @@ class AsymmetricAES(object):
 		# checks.
 		file_path = FilePath(input)
 		if not file_path.exists():
-			return r3sponse.error(f"Input [{input}] does not exist.")
+			return Response.error(f"Input [{input}] does not exist.")
 		if file_path.directory():
-			return r3sponse.error(f"Input path [{input}] is a directory.")
+			return Response.error(f"Input path [{input}] is a directory.")
 
 		# dir path.
 		if output == None:
 			if ".enc.zip" not in input:
-				return r3sponse.error(f"Invalid input format [{input}], the format must end with [***.enc.zip]")
+				return Response.error(f"Invalid input format [{input}], the format must end with [***.enc.zip]")
 			dir_path = output.replace(".enc.zip", "/").replace("//","/").replace("//","/").replace("//","/")
 		else:
 			if ".enc.zip" in output:
-				return r3sponse.error(f"Invalid output format [{output}], the format can not end with [***.enc.zip]")
+				return Response.error(f"Invalid output format [{output}], the format can not end with [***.enc.zip]")
 			dir_path = output.replace(".enc.zip", "/")
 
 		# check output.
 		l_dir_path = dir_path
 		if l_dir_path[len(l_dir_path)-1] == "/": l_dir_path = l_dir_path[:-1]
 		if Files.exists(l_dir_path):
-			return r3sponse.error(f"Output path [{l_dir_path}] already exists.")
+			return Response.error(f"Output path [{l_dir_path}] already exists.")
 		
 		# decrypt zip.
 		tmp_zip = f"/tmp/{FilePath(input).name()}"
 		if Files.exists(tmp_zip): os.system(f"rm -fr {tmp_zip}")
 		response = self.decrypt_file(input=input, output=tmp_zip, remove=False, base64_encoding=True)
 		if not response.success:
-			return r3sponse.error(f"Failed to decrypted directory [{input}], error: {response.error}")
+			return Response.error(f"Failed to decrypted directory [{input}], error: {response.error}")
 
 		# extract zip.
 		tmp_extract = f"/tmp/{String('').generate(length=32,capitalize=True,digits=True)}/"
@@ -334,15 +334,15 @@ class AsymmetricAES(object):
 				if remove and input != output:
 					try: os.remove(input)
 					except PermissionError: os.system(f"sudo rm -fr {input}")
-				return r3sponse.success(f"Successfully decrypted directory [{input}].")
+				return Response.success(f"Successfully decrypted directory [{input}].")
 			else:
 				os.system(f"rm -fr {tmp_extract}")
 				os.system(f"rm -fr {tmp_zip}")
-				return r3sponse.error(f"Failed to decrypt directory [{input}].")
+				return Response.error(f"Failed to decrypt directory [{input}].")
 		else:
 			os.system(f"rm -fr {tmp_extract}")
 			os.system(f"rm -fr {tmp_zip}")
-			return r3sponse.error(f"Failed to decrypt directory [{input}].")
+			return Response.error(f"Failed to decrypt directory [{input}].")
 
 		#
 
@@ -370,7 +370,7 @@ class Database(object):
 		#self.__class__.__name__ = "Database"
 
 		# check params.
-		response = r3sponse.parameters.check({
+		response = Response.parameters.check({
 			"aes:object":aes,
 			"path:str":path,})
 		if not response.success: raise ValueError(response.error)
@@ -381,7 +381,7 @@ class Database(object):
 		self.file_path = self.fp = FilePath(self.path)
 		if not self.fp.exists():
 			os.system(f"mkdir {self.fp.path}")
-			self.fp.ownership.set(owner=syst3m.defaults.vars.owner)
+			self.fp.ownership.set(owner=Defaults.vars.owner)
 			self.fp.permission.set(permission=770)
 
 		#
@@ -398,14 +398,14 @@ class Database(object):
 			
 		# check root.
 		if not Files.exists(f"{self.path}"):
-			return r3sponse.error(f"Encrypted database root [{self.path}] does not exist.")
+			return Response.error(f"Encrypted database root [{self.path}] does not exist.")
 
 		# activate keys.
 		response = self.aes.load_keys()
 		if not response.success: return response
 
 		# success.
-		return r3sponse.success(f"Successfully activated encrypted database [{self.path}].")
+		return Response.success(f"Successfully activated encrypted database [{self.path}].")
 
 		#
 	def check(self, 
@@ -416,8 +416,8 @@ class Database(object):
 		# save the changes.
 		save=True,
 	):
-		if not self.activated: return r3sponse.error(f"Encrypted database {self.path} is not activated yet, call database.activate() first.")
-		response = r3sponse.parameters.check({
+		if not self.activated: return Response.error(f"Encrypted database {self.path} is not activated yet, call database.activate() first.")
+		response = Response.parameters.check({
 			"path:str":path,
 			"default:str,dict,list,int,float":default,
 			"save:bool":save,})
@@ -427,7 +427,7 @@ class Database(object):
 		format, content = response.unpack(["format", "content"])
 		response = content.check(default=default, save=save)
 		if not response.success: return response
-		return r3sponse.success(f"Successfully checked content {path}.", {
+		return Response.success(f"Successfully checked content {path}.", {
 			"content":content,
 			"format":format,
 		})
@@ -437,63 +437,63 @@ class Database(object):
 		# the default data, specify to call self.check() automatically on the data object.
 		default=None,
 	):
-		if not self.activated: return r3sponse.error(f"Encrypted database [{self.path}] is not activated yet, call database.activate() first.")
-		response = r3sponse.parameters.check({
+		if not self.activated: return Response.error(f"Encrypted database [{self.path}] is not activated yet, call database.activate() first.")
+		response = Response.parameters.check({
 			"path:str":path,})
 		if not response.success: return response
 		path = gfp.clean(f"{self.path}/{path}", remove_last_slash=True, remove_double_slash=True)
 		if not os.path.exists(str(path)):
 			if default == None:
-				return r3sponse.error(f"Specified path [{path}] does not exist.")
+				return Response.error(f"Specified path [{path}] does not exist.")
 			elif isinstance(default, (str, String, File)):
 				if isinstance(default, File):
 					default = default.data
-				return r3sponse.success(f"Successfully parsed {path}.", {
+				return Response.success(f"Successfully parsed {path}.", {
 					"format":"File",
 					"content":self.File(path=path, default=str(default), aes=self.aes),
 				})
 			elif isinstance(default, (list, Array)):
-				return r3sponse.success(f"Successfully parsed {path}.", {
+				return Response.success(f"Successfully parsed {path}.", {
 					"format":"Array",
 					"content":self.Array(path=path, default=default, aes=self.aes),
 				})
 			elif isinstance(default, (dict, Dictionary)):
-				return r3sponse.success(f"Successfully parsed {path}.", {
+				return Response.success(f"Successfully parsed {path}.", {
 					"format":"Dictionary",
 					"content":self.Dictionary(path=path, default=default, aes=self.aes),
 				})
 		else:
 			try:
 				format, _ = unpack(Files.load(path))
-			except Exception as e: return r3sponse.error(f"Failed to load content {path}, {e}.")
+			except Exception as e: return Response.error(f"Failed to load content {path}, {e}.")
 			if format in ["list", "Array"]:
-				return r3sponse.success(f"Successfully parsed {path}.", {
+				return Response.success(f"Successfully parsed {path}.", {
 					"format":"Array",
 					"content":self.Array(path=path, default=default, aes=self.aes),
 				})
 			elif format in ["dict", "Dictionary"]:
-				return r3sponse.success(f"Successfully parsed {path}.", {
+				return Response.success(f"Successfully parsed {path}.", {
 					"format":"Dictionary",
 					"content":self.Dictionary(path=path, default=default, aes=self.aes),
 				})
 			elif format in ["file", "File"]:
-				return r3sponse.success(f"Successfully parsed {path}.", {
+				return Response.success(f"Successfully parsed {path}.", {
 					"format":"File",
 					"content":self.File(path=path, default=default, aes=self.aes),
 				})
 			else:
-				return r3sponse.error(f"Unknown format [{format}] for path [{path}].")
+				return Response.error(f"Unknown format [{format}] for path [{path}].")
 	def save(self, 
 		# the content object (! param number 1).
 		content=None,
 	):
-		if not self.activated: return r3sponse.error(f"Encrypted database {self.path} is not activated yet, call database.activate() first.")
-		response = r3sponse.parameters.check({
+		if not self.activated: return Response.error(f"Encrypted database {self.path} is not activated yet, call database.activate() first.")
+		response = Response.parameters.check({
 			"content:object":content,})
 		if not response.success: return response
 		response = content.save()
 		if not response.success: return response
-		return r3sponse.success(f"Successfully saved content {path}.")
+		return Response.success(f"Successfully saved content {path}.")
 
 	# properties.
 	@property
@@ -529,24 +529,24 @@ class Database(object):
 		def load(self):
 			try:
 				format, content = unpack(Files.load(self.path))
-			except Exception as e: return r3sponse.error(f"Failed to load content {self.path}, {e}.")
+			except Exception as e: return Response.error(f"Failed to load content {self.path}, {e}.")
 			response = self.aes.decrypt(content.encode())
 			if not response.success: return response
 			decrypted = response.decrypted.decode()
 			self.data = decrypted
 			self.format = format
 			self.loaded = True
-			return r3sponse.success(f"Successfully loaded content {self.path}.")
+			return Response.success(f"Successfully loaded content {self.path}.")
 		def save(self):
 			if not self.loaded:
-				return r3sponse.error("The data object is not loaded yet, you must call content.load() first.")
+				return Response.error("The data object is not loaded yet, you must call content.load() first.")
 			content = Formats.denitialize(self.content)
 			response = self.aes.encrypt(content)
 			if not response.success: return response
 			try:
 				content = utils.__save_bytes__(str(self.path), f"{self.format} ".encode()+response.encrypted)
-			except Exception as e: return r3sponse.error(f"Failed to save content {self.path}, {e}.")
-			return r3sponse.success(f"Successfully saved content {self.path}.")
+			except Exception as e: return Response.error(f"Failed to save content {self.path}, {e}.")
+			return Response.success(f"Successfully saved content {self.path}.")
 
 	# a array data object
 	class Array(Array):
@@ -570,29 +570,29 @@ class Database(object):
 		def load(self):
 			try:
 				format, content = unpack(Files.load(self.path))
-			except Exception as e: return r3sponse.error(f"Failed to load content {self.path}, {e}.")
+			except Exception as e: return Response.error(f"Failed to load content {self.path}, {e}.")
 			response = self.aes.decrypt(content.encode())
 			if not response.success: return response
 			decrypted = response.decrypted.decode()
 			try:
 				content = json.loads(decrypted)
-			except Exception as e: return r3sponse.error(f"Failed to serialize content {self.path}, {e}.")
+			except Exception as e: return Response.error(f"Failed to serialize content {self.path}, {e}.")
 			self.array = content
 			self.format = format
 			self.loaded = True
-			return r3sponse.success(f"Successfully loaded content {self.path}.")
+			return Response.success(f"Successfully loaded content {self.path}.")
 		def save(self):
 			if not self.loaded:
-				return r3sponse.error("The data object is not loaded yet, you must call content.load() first.")
+				return Response.error("The data object is not loaded yet, you must call content.load() first.")
 			try:
 				content = json.dumps(Formats.denitialize(self.array))
-			except Exception as e: return r3sponse.error(f"Failed to dump content {self.path}, {e}.")
+			except Exception as e: return Response.error(f"Failed to dump content {self.path}, {e}.")
 			response = self.aes.encrypt(content)
 			if not response.success: return response
 			try:
 				content = utils.__save_bytes__(str(self.path), f"{self.format} ".encode()+response.encrypted)
-			except Exception as e: return r3sponse.error(f"Failed to save content {self.path}, {e}.")
-			return r3sponse.success(f"Successfully saved content {self.path}.")
+			except Exception as e: return Response.error(f"Failed to save content {self.path}, {e}.")
+			return Response.success(f"Successfully saved content {self.path}.")
 
 	# a dictionary data object
 	class Dictionary(Dictionary):
@@ -616,29 +616,29 @@ class Database(object):
 		def load(self):
 			try:
 				format, content = unpack(Files.load(self.path))
-			except Exception as e: return r3sponse.error(f"Failed to load content {self.path}, {e}.")
+			except Exception as e: return Response.error(f"Failed to load content {self.path}, {e}.")
 			response = self.aes.decrypt(content.encode())
 			if not response.success: return response
 			decrypted = response.decrypted.decode()
 			try:
 				content = json.loads(decrypted)
-			except Exception as e: return r3sponse.error(f"Failed to serialize content {self.path}, {e}.")
+			except Exception as e: return Response.error(f"Failed to serialize content {self.path}, {e}.")
 			self.dictionary = content
 			self.format = format
 			self.loaded = True
-			return r3sponse.success(f"Successfully loaded content {self.path}.")
+			return Response.success(f"Successfully loaded content {self.path}.")
 		def save(self):
 			if not self.loaded:
-				return r3sponse.error("The data object is not loaded yet, you must call content.load() first.")
+				return Response.error("The data object is not loaded yet, you must call content.load() first.")
 			try:
 				content = json.dumps(Formats.denitialize(self.dictionary))
-			except Exception as e: return r3sponse.error(f"Failed to dump content {self.path}, {e}.")
+			except Exception as e: return Response.error(f"Failed to dump content {self.path}, {e}.")
 			response = self.aes.encrypt(content)
 			if not response.success: return response
 			try:
 				content = utils.__save_bytes__(str(self.path), f"{self.format} ".encode()+response.encrypted)
-			except Exception as e: return r3sponse.error(f"Failed to save content {self.path}, {e}.")
-			return r3sponse.success(f"Successfully saved content {self.path}.")
+			except Exception as e: return Response.error(f"Failed to save content {self.path}, {e}.")
+			return Response.success(f"Successfully saved content {self.path}.")
 
 
 """
