@@ -3,17 +3,16 @@
 
 # imports.
 import os, sys, ast, json, glob, platform, random
-import syst3m, cl1
-from r3sponse import r3sponse
-from fil3s import *
+import syst3m
+from dev0s import *
 
 # source.
 ALIAS = "encrypti0n"
 SOURCE_NAME = "encrypti0n"
-SOURCE_PATH = syst3m.defaults.source_path(__file__, back=3)
-BASE = syst3m.defaults.source_path(SOURCE_PATH)
-OS = syst3m.defaults.operating_system(supported=["linux", "macos"])
-syst3m.defaults.alias(alias=ALIAS, executable=f"{SOURCE_PATH}/", sudo=True)
+SOURCE_PATH = Defaults.source_path(__file__, back=3)
+BASE = Defaults.source_path(SOURCE_PATH)
+OS = Defaults.operating_system(supported=["linux", "macos"])
+Defaults.alias(alias=ALIAS, executable=f"{SOURCE_PATH}/", sudo=True)
 
 # file settings.
 ADMINISTRATOR = "administrator"
