@@ -11,7 +11,7 @@ from Crypto.PublicKey import RSA as _RSA_
 from Crypto.Cipher import PKCS1_OAEP
 
 # inc imports.
-from fil3s import *
+from dev0s import *
 
 # the encryption class.
 class RSA(object):
@@ -56,9 +56,6 @@ class RSA(object):
 	# key management.
 	def generate_keys(self, log_level=0):
 
-		# default response.
-		response = utils.__default_response__()
-
 		# set dir,
 		directory = str(self.directory)
 		private_key_path = str(self.private_key)
@@ -67,13 +64,13 @@ class RSA(object):
 		# checks.
 		if not self.memory:
 			if log_level >= 0: 
-				loader = syst3m.console.Loader(f"Generating key {self.directory}")
+				loader = Console.Loader(f"Generating key {self.directory}")
 			if Files.exists(directory): 
 				loader.stop(success=False)
 				response["error"] = f"Key [{directory}] already exists."
 				return response
 		else:
-			if log_level >= 0: loader = syst3m.console.Loader("Generating key")
+			if log_level >= 0: loader = Console.Loader("Generating key")
 		
 		# generate.
 		key_pair = _RSA_.generate(4096, e=65537)
@@ -95,7 +92,7 @@ class RSA(object):
 			utils.__set_file_path_permission__(public_key_path, permission=644)
 		# response.
 		loader.stop()
-		return r3sponse.success(f"Successfully generated key {directory}.", {
+		return Response.success(f"Successfully generated key {directory}.", {
 			"private_key":private_key_pem.decode(),
 			"public_key":public_key_pem.decode(),
 		})
@@ -104,7 +101,6 @@ class RSA(object):
 	def load_keys(self):
 
 		# load keys.
-		response = utils.__default_response__()
 		if not self.memory:
 			self.private_key_data = Files.load(self.private_key)
 			self.public_key_data = Files.load(self.public_key)
@@ -125,17 +121,16 @@ class RSA(object):
 			self.public_key_object = None
 			self.private_key_object = None
 			if "Padding is incorrect" in str(e):
-				return r3sponse.error("Provided an incorrect passphrase.")
-			else: return r3sponse.error(f"ValueError: {e}")
+				return Response.error("Provided an incorrect passphrase.")
+			else: return Response.error(f"ValueError: {e}")
 		
 		# response.
-		return r3sponse.success("Successfully loaded the key pair.")
+		return Response.success("Successfully loaded the key pair.")
 
 		#
 	def load_public_key(self):
 
 		# load keys.
-		response = utils.__default_response__()
 		if not self.memory:
 			self.public_key_data = Files.load(self.public_key)
 		else:
@@ -152,13 +147,12 @@ class RSA(object):
 			return response
 		
 		# response.
-		return r3sponse.success("Successfully loaded the key pair.")
+		return Response.success("Successfully loaded the key pair.")
 
 		#
 	def load_private_key(self):
 
 		# load keys.
-		response = utils.__default_response__()
 		if not self.memory:
 			self.private_key_data = Files.load(self.private_key)
 		else:
@@ -185,7 +179,7 @@ class RSA(object):
 				return response
 		
 		# response.
-		return r3sponse.success("Successfully loaded the key pair.")
+		return Response.success("Successfully loaded the key pair.")
 
 		#
 	def edit_passphrase(self, passphrase=None):
@@ -201,7 +195,6 @@ class RSA(object):
 		output = utils.__execute__(["ssh-keygen", "-p", "-P", f"{self.passphrase}", "-N", f"{passphrase}", "-f", f"{private_key}"])
 
 		# response.
-		response = utils.__default_response__()
 		if "Your identification has been saved with the new passphrase." in output:
 			self.private_key_data = str(Files.load(private_key))
 			if not self.memory:
@@ -221,10 +214,9 @@ class RSA(object):
 
 		# checks.
 		if not self.public_key_activated:
-			return r3sponse.error("Can not encrypt data since the public key is not activated yet.")
+			return Response.error("Can not encrypt data since the public key is not activated yet.")
 
 		# encrypt.
-		response = utils.__default_response__()
 		encrypted = self.__encrypt_blob__(string, self.public_key_object)
 
 		# layers.
@@ -244,10 +236,9 @@ class RSA(object):
 
 		# checks.
 		if not self.public_key_activated:
-			return r3sponse.error("Can not encrypt data since the public key is not activated yet.")
+			return Response.error("Can not encrypt data since the public key is not activated yet.")
 
 		# encrypt.
-		response = utils.__default_response__()
 		bytes = utils.__load_bytes__(path)
 		encrypted = self.__encrypt_blob__(bytes, self.public_key_object)
 		utils.__save_bytes__(path, encrypted)
@@ -256,15 +247,15 @@ class RSA(object):
 		if layers-1 > 0:
 			return self.encrypt_file(path, layers=layers-1)
 		else:
-			return r3sponse.success(f"Successfully encrypted file [{path}].")
+			return Response.success(f"Successfully encrypted file [{path}].")
 
 		#
 	def encrypt_directory(self, path, recursive=False, layers=1):
-		response = utils.__default_response__()
+
 
 		# checks.
 		if not self.public_key_activated:
-			return r3sponse.error("Can not encrypt data since the public key is not activated yet.")
+			return Response.error("Can not encrypt data since the public key is not activated yet.")
 
 		# recursively encrypt all files.
 		if recursive:
@@ -282,11 +273,10 @@ class RSA(object):
 						return response
 
 			# success.
-			response = utils.__default_response__()
 			if layers-1 > 0:
 				return self.encrypt_directory(path, recursive=True, layers=layers-1)
 			else:
-				return r3sponse.success(f"Successfully encrypted directory [{path}] (recursively).")
+				return Response.success(f"Successfully encrypted directory [{path}] (recursively).")
 
 
 		# encrypt the directory and save to x.encrypted.zip file.
@@ -309,7 +299,6 @@ class RSA(object):
 			zip.create(source=path)
 
 			# encrypt zip.
-			response = utils.__default_response__()
 			response = self.encrypt_file(zip.file_path.path, layers=layers)
 			if response["success"]:
 				file_path.delete(forced=True)
@@ -325,10 +314,9 @@ class RSA(object):
 		
 		# checks.
 		if not self.private_key_activated:
-			return r3sponse.error("Can not decrypt data since the private key is not activated yet.")
+			return Response.error("Can not decrypt data since the private key is not activated yet.")
 
 		# decrypt.
-		response = utils.__default_response__()
 		if isinstance(string,str): string = string.encode()
 		decrypted = self.__decrypt_blob__(string, self.private_key_object)
 		
@@ -349,10 +337,9 @@ class RSA(object):
 
 		# checks.
 		if not self.private_key_activated:
-			return r3sponse.error("Can not decrypt data since the private key is not activated yet.")
+			return Response.error("Can not decrypt data since the private key is not activated yet.")
 
 		# encrypt.
-		response = utils.__default_response__()
 		bytes = utils.__load_bytes__(path)
 		decrypted = self.__decrypt_blob__(bytes, self.private_key_object)
 		utils.__save_bytes__(path, decrypted)
@@ -370,10 +357,9 @@ class RSA(object):
 
 		# checks.
 		if not self.private_key_activated:
-			return r3sponse.error("Can not decrypt data since the private key is not activated yet.")
+			return Response.error("Can not decrypt data since the private key is not activated yet.")
 
 		# defaults.
-		response = utils.__default_response__()
 
 		# recursively decrypt all files.
 		if recursive:
@@ -391,7 +377,6 @@ class RSA(object):
 						return response
 
 			# success.
-			response = utils.__default_response__()
 			if layers-1 > 0:
 				return self.decrypt_directory(path, recursive=True, layers=layers-1)
 			else:
@@ -421,7 +406,6 @@ class RSA(object):
 				return response
 
 			# extract zip.
-			response = utils.__default_response__()
 			zip = Zip(path=zip_path)
 			zip.extract(base=None)
 			if Files.exists(path):
@@ -571,7 +555,6 @@ class EncryptedDictionary(Dictionary):
 		self.layers = layers
 
 	def initialize(self):
-		response = utils.__default_response__()
 
 		# init encryption,
 		self.encryption = RSA(
@@ -581,7 +564,6 @@ class EncryptedDictionary(Dictionary):
 		if response["error"] != None: return response
 
 		# checks.
-		response = utils.__default_response__()
 		created = False
 		if not self._file_.file_path.exists():
 			self._file_.save(json.dumps(self.default, indent=4, ensure_ascii=False))
@@ -597,7 +579,6 @@ class EncryptedDictionary(Dictionary):
 			if response["error"] != None: return response
 
 		# success.
-		response = utils.__default_response__()
 		response["success"] = True
 		response["message"] = f"Successfully initialized encrypted dictionary [{self.file_path.path}]."
 		return response
@@ -611,7 +592,6 @@ class EncryptedDictionary(Dictionary):
 		decrypted = response["decrypted"]
 
 		# handle.
-		response = utils.__default_response__()
 		try:
 			self.dictionary = json.loads(decrypted)
 			response["success"] = True
@@ -634,7 +614,6 @@ class EncryptedDictionary(Dictionary):
 		encrypted = response["encrypted"]
 
 		# handle.
-		response = utils.__default_response__()
 		try:
 			self._file_.save(encrypted)
 			response["success"] = True
@@ -649,7 +628,6 @@ class EncryptedDictionary(Dictionary):
 	def check(self, default=None, save=True):
 
 		# checks.
-		response = utils.__default_response__()
 		if not isinstance(default, dict): 
 			response["error"] = "Parameter [default] must be a dictionary."
 			return response
@@ -658,7 +636,6 @@ class EncryptedDictionary(Dictionary):
 			return response
 
 		# handle.
-		response = utils.__default_response__()
 		try:
 			old = ast.literal_eval(str(self.dictionary))
 			self._dictionary_.dictionary = self.dictionary
@@ -668,7 +645,6 @@ class EncryptedDictionary(Dictionary):
 			return response
 
 		# save.
-		response = utils.__default_response__()
 		if save and old != self.dictionary:
 			response = self.save()
 			if response["error"] != None: 
